showBarrierForNotModalDialog property
When true, a scrim is also shown for non-modal (modeless) child dialogs. Tapping the scrim focuses the topmost modeless dialog.
Implementation
final bool showBarrierForNotModalDialog;
When true, a scrim is also shown for non-modal (modeless) child dialogs. Tapping the scrim focuses the topmost modeless dialog.
final bool showBarrierForNotModalDialog;